# Giphy Core Client for Ruby

The **Giphy Core SDK** is a wrapper around [Giphy API](https://github.com/Giphy/GiphyAPI).

[![Build Status](https://travis-ci.com/Giphy/giphy-ruby-client.svg?token=ytpQbMSuy8sydsqZwbwp&branch=master)](https://travis-ci.com/Giphy/giphy-ruby-client)

[Giphy](https://www.giphy.com) is the best way to search, share, and discover GIFs on the Internet. Similar to the way other search engines work, the majority of our content comes from indexing based on the best and most popular GIFs and search terms across the web. We organize all those GIFs so you can find the good content easier and share it out through your social channels. We also feature some of our favorite GIF artists and work with brands to create and promote their original GIF content.

[![](https://media.giphy.com/media/5xaOcLOqNmWHaLeB14I/giphy.gif)]()

# Getting Started

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.9.3
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build GiphyClient.gemspec
```

Then either install the gem locally:

```shell
gem install ./GiphyClient-1.0.0.gem
```
(for development, run `gem install --dev ./GiphyClient-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'GiphyClient', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'GiphyClient', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'GiphyClient'

api_instance = GiphyClient::DefaultApi.new

api_key = "dc6zaTOxFJmzC" # String | Giphy API Key.

category = "category_example" # String | Filters results by category.

opts = { 
  limit: 25, # Integer | The maximum number of records to return.
  offset: 0, # Integer | An optional results offset. Defaults to 0.
}

begin
  #Category Tags Endpoint.
  result = api_instance.gifs_categories_category_get(api_keycategory, , opts)
  p result
rescue GiphyClient::ApiError => e
  puts "Exception when calling DefaultApi->gifs_categories_category_get: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://api.giphy.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*GiphyClient::DefaultApi* | [**gifs_categories_category_get**](docs/DefaultApi.md#gifs_categories_category_get) | **GET** /gifs/categories/{category} | Category Tags Endpoint.
*GiphyClient::DefaultApi* | [**gifs_categories_category_tag_get**](docs/DefaultApi.md#gifs_categories_category_tag_get) | **GET** /gifs/categories/{category}/{tag} | Tagged Gifs Endpoint.
*GiphyClient::DefaultApi* | [**gifs_categories_get**](docs/DefaultApi.md#gifs_categories_get) | **GET** /gifs/categories | Categories Endpoint.
*GiphyClient::DefaultApi* | [**gifs_get**](docs/DefaultApi.md#gifs_get) | **GET** /gifs | Get GIFs by ID Endpoint
*GiphyClient::DefaultApi* | [**gifs_gif_id_get**](docs/DefaultApi.md#gifs_gif_id_get) | **GET** /gifs/{gif_id} | Get GIF by ID Endpoint
*GiphyClient::DefaultApi* | [**gifs_random_get**](docs/DefaultApi.md#gifs_random_get) | **GET** /gifs/random | Random Endpoint
*GiphyClient::DefaultApi* | [**gifs_search_get**](docs/DefaultApi.md#gifs_search_get) | **GET** /gifs/search | Search Endpoint
*GiphyClient::DefaultApi* | [**gifs_translate_get**](docs/DefaultApi.md#gifs_translate_get) | **GET** /gifs/translate | Translate Endpoint
*GiphyClient::DefaultApi* | [**gifs_trending_get**](docs/DefaultApi.md#gifs_trending_get) | **GET** /gifs/trending | Trending GIFs Endpoint
*GiphyClient::DefaultApi* | [**stickers_random_get**](docs/DefaultApi.md#stickers_random_get) | **GET** /stickers/random | Random Sticker Endpoint
*GiphyClient::DefaultApi* | [**stickers_search_get**](docs/DefaultApi.md#stickers_search_get) | **GET** /stickers/search | Sticker Search Endpoint
*GiphyClient::DefaultApi* | [**stickers_translate_get**](docs/DefaultApi.md#stickers_translate_get) | **GET** /stickers/translate | Sticker Translate Endpoint
*GiphyClient::DefaultApi* | [**stickers_trending_get**](docs/DefaultApi.md#stickers_trending_get) | **GET** /stickers/trending | Trending Stickers Endpoint


## Documentation for Models

 - [GiphyClient::BaseChannelModel](docs/BaseChannelModel.md)
 - [GiphyClient::BaseChannelModelGifs](docs/BaseChannelModelGifs.md)
 - [GiphyClient::Breadcrumb](docs/Breadcrumb.md)
 - [GiphyClient::Category](docs/Category.md)
 - [GiphyClient::ChannelWithChildrenModel](docs/ChannelWithChildrenModel.md)
 - [GiphyClient::ChannelWithChildrenModelChildren](docs/ChannelWithChildrenModelChildren.md)
 - [GiphyClient::Gif](docs/Gif.md)
 - [GiphyClient::GifImages](docs/GifImages.md)
 - [GiphyClient::GifImagesDownsized](docs/GifImagesDownsized.md)
 - [GiphyClient::GifImagesDownsizedLarge](docs/GifImagesDownsizedLarge.md)
 - [GiphyClient::GifImagesDownsizedMedium](docs/GifImagesDownsizedMedium.md)
 - [GiphyClient::GifImagesDownsizedSmall](docs/GifImagesDownsizedSmall.md)
 - [GiphyClient::GifImagesDownsizedStill](docs/GifImagesDownsizedStill.md)
 - [GiphyClient::GifImagesFixedHeight](docs/GifImagesFixedHeight.md)
 - [GiphyClient::GifImagesFixedHeightDownsampled](docs/GifImagesFixedHeightDownsampled.md)
 - [GiphyClient::GifImagesFixedHeightSmall](docs/GifImagesFixedHeightSmall.md)
 - [GiphyClient::GifImagesFixedHeightSmallStill](docs/GifImagesFixedHeightSmallStill.md)
 - [GiphyClient::GifImagesFixedHeightStill](docs/GifImagesFixedHeightStill.md)
 - [GiphyClient::GifImagesFixedWidth](docs/GifImagesFixedWidth.md)
 - [GiphyClient::GifImagesFixedWidthDownsampled](docs/GifImagesFixedWidthDownsampled.md)
 - [GiphyClient::GifImagesFixedWidthSmall](docs/GifImagesFixedWidthSmall.md)
 - [GiphyClient::GifImagesFixedWidthSmallStill](docs/GifImagesFixedWidthSmallStill.md)
 - [GiphyClient::GifImagesFixedWidthStill](docs/GifImagesFixedWidthStill.md)
 - [GiphyClient::GifImagesLooping](docs/GifImagesLooping.md)
 - [GiphyClient::GifImagesOriginal](docs/GifImagesOriginal.md)
 - [GiphyClient::GifImagesOriginalStill](docs/GifImagesOriginalStill.md)
 - [GiphyClient::GifImagesPreview](docs/GifImagesPreview.md)
 - [GiphyClient::GifImagesPreviewGif](docs/GifImagesPreviewGif.md)
 - [GiphyClient::InlineResponse200](docs/InlineResponse200.md)
 - [GiphyClient::InlineResponse2001](docs/InlineResponse2001.md)
 - [GiphyClient::InlineResponse2002](docs/InlineResponse2002.md)
 - [GiphyClient::InlineResponse2003](docs/InlineResponse2003.md)
 - [GiphyClient::InlineResponse2004](docs/InlineResponse2004.md)
 - [GiphyClient::InlineResponse2005](docs/InlineResponse2005.md)
 - [GiphyClient::InlineResponse400](docs/InlineResponse400.md)
 - [GiphyClient::LastChildModel](docs/LastChildModel.md)
 - [GiphyClient::LastChildModelChildren](docs/LastChildModelChildren.md)
 - [GiphyClient::MetaContent](docs/MetaContent.md)
 - [GiphyClient::MetaObject](docs/MetaObject.md)
 - [GiphyClient::Pagination](docs/Pagination.md)
 - [GiphyClient::RandomGif](docs/RandomGif.md)
 - [GiphyClient::ShallowTag](docs/ShallowTag.md)
 - [GiphyClient::Tag](docs/Tag.md)
 - [GiphyClient::TrendingTag](docs/TrendingTag.md)
 - [GiphyClient::User](docs/User.md)

